@@ -237,6 +237,14 @@ func TestFullPipe(t *testing.T) {
 			},
 			expectedRunError: `template: tmpl:1: unexpected "}" in operand`,
 		},
+		"invalid_tap_skip_upload_template": {
+			prepare: func(ctx *context.Context) {
+				ctx.Config.Brews[0].SkipUpload = "{{ .Asdsa }"
+				ctx.Config.Brews[0].Tap.Owner = "test"
+				ctx.Config.Brews[0].Tap.Name = "test"
+			},
+			expectedRunError: `template: tmpl:1: unexpected "}" in operand`,
+		},
 	} {
 		t.Run(name, func(t *testing.T) {
 			folder := t.TempDir()
@@ -387,7 +395,8 @@ func TestRunPipeMultipleBrewsWithSkip(t *testing.T) {
 		Version:   "1.0.1",
 		Artifacts: artifact.New(),
 		Env: map[string]string{
-			"FOO_BAR": "is_bar",
+			"FOO_BAR":     "is_bar",
+			"SKIP_UPLOAD": "true",
 		},
 		Config: config.Project{
 			Dist:        folder,
@@ -425,6 +434,17 @@ func TestRunPipeMultipleBrewsWithSkip(t *testing.T) {
 					},
 					SkipUpload: "true",
 				},
+				{
+					Name: "baz",
+					Tap: config.RepoRef{
+						Owner: "foo",
+						Name:  "bar",
+					},
+					IDs: []string{
+						"foo",
+					},
+					SkipUpload: "{{ .Env.SKIP_UPLOAD }}",
+				},
 			},
 		},
 	}
@@ -787,6 +807,9 @@ func TestRunPipeNoUpload(t *testing.T) {
 			},
 		},
 	})
+	ctx.Env = map[string]string{
+		"SKIP_UPLOAD": "true",
+	}
 	ctx.TokenType = context.TokenTypeGitHub
 	ctx.Git = context.GitInfo{CurrentTag: "v1.0.1"}
 	path := filepath.Join(folder, "whatever.tar.gz")
@@ -817,6 +840,11 @@ func TestRunPipeNoUpload(t *testing.T) {
 		ctx.Semver.Prerelease = ""
 		assertNoPublish(t)
 	})
+	t.Run("skip upload true set by template", func(t *testing.T) {
+		ctx.Config.Brews[0].SkipUpload = "{{.Env.SKIP_UPLOAD}}"
+		ctx.Semver.Prerelease = ""
+		assertNoPublish(t)
+	})
 	t.Run("skip upload auto", func(t *testing.T) {
 		ctx.Config.Brews[0].SkipUpload = "auto"
 		ctx.Semver.Prerelease = "beta1"
@@ -870,26 +898,6 @@ func TestDefault(t *testing.T) {
 			Brews: []config.Homebrew{
 				{},
 			},
-			Builds: []config.Build{
-				{
-					Binary: "foo",
-					Goos:   []string{"linux", "darwin"},
-					Goarch: []string{"386", "amd64"},
-				},
-				{
-					Binary: "bar",
-					Goos:   []string{"linux", "darwin"},
-					Goarch: []string{"386", "amd64"},
-					Ignore: []config.IgnoredBuild{
-						{Goos: "darwin", Goarch: "amd64"},
-					},
-				},
-				{
-					Binary: "foobar",
-					Goos:   []string{"linux"},
-					Goarch: []string{"amd64"},
-				},
-			},
 		},
 	}
 	require.NoError(t, Pipe{}.Default(ctx))
@@ -897,7 +905,6 @@ func TestDefault(t *testing.T) {
 	require.NotEmpty(t, ctx.Config.Brews[0].CommitAuthor.Name)
 	require.NotEmpty(t, ctx.Config.Brews[0].CommitAuthor.Email)
 	require.NotEmpty(t, ctx.Config.Brews[0].CommitMessageTemplate)
-	require.Equal(t, `bin.install "myproject"`, ctx.Config.Brews[0].Install)
 }
 
 func TestGHFolder(t *testing.T) {
@@ -928,3 +935,100 @@ func TestRunSkipNoName(t *testing.T) {
 	client := client.NewMock()
 	testlib.AssertSkipped(t, runAll(ctx, client))
 }
+
+func TestInstalls(t *testing.T) {
+	t.Run("provided", func(t *testing.T) {
+		require.Equal(t, []string{
+			`bin.install "foo"`,
+			`bin.install "bar"`,
+		}, installs(
+			config.Homebrew{Install: "bin.install \"foo\"\nbin.install \"bar\""},
+			[]*artifact.Artifact{},
+		))
+	})
+
+	t.Run("from artifacts", func(t *testing.T) {
+		require.Equal(t, []string{
+			`bin.install "foo"`,
+			`bin.install "bar"`,
+		}, installs(
+			config.Homebrew{},
+			[]*artifact.Artifact{
+				{
+					Extra: map[string]interface{}{
+						"Binaries": []string{"foo", "bar"},
+					},
+				},
+				{
+					Extra: map[string]interface{}{
+						"Binaries": []string{"foo"},
+					},
+				},
+				{
+					Extra: map[string]interface{}{
+						"Binaries": []string{"bar"},
+					},
+				},
+				{
+					Extra: map[string]interface{}{
+						"Binaries": []string{"bar", "foo"},
+					},
+				},
+			},
+		))
+	})
+}
+
+func TestRunPipeUniversalBinary(t *testing.T) {
+	folder := t.TempDir()
+	ctx := &context.Context{
+		Git: context.GitInfo{
+			CurrentTag: "v1.0.1",
+		},
+		Version:   "1.0.1",
+		Artifacts: artifact.New(),
+		Config: config.Project{
+			Dist:        folder,
+			ProjectName: "unibin",
+			Brews: []config.Homebrew{
+				{
+					Name: "unibin",
+					Tap: config.RepoRef{
+						Owner: "unibin",
+						Name:  "bar",
+					},
+					IDs: []string{
+						"unibin",
+					},
+					Install: `bin.install "unibin"`,
+				},
+			},
+		},
+	}
+	path := filepath.Join(folder, "bin.tar.gz")
+	ctx.Artifacts.Add(&artifact.Artifact{
+		Name:   "bin.tar.gz",
+		Path:   path,
+		Goos:   "darwin",
+		Goarch: "all",
+		Type:   artifact.UploadableArchive,
+		Extra: map[string]interface{}{
+			"ID":     "unibin",
+			"Format": "tar.gz",
+		},
+	})
+
+	f, err := os.Create(path)
+	require.NoError(t, err)
+	require.NoError(t, f.Close())
+	client := client.NewMock()
+	distFile := filepath.Join(folder, "unibin.rb")
+
+	require.NoError(t, runAll(ctx, client))
+	require.NoError(t, publishAll(ctx, client))
+	require.True(t, client.CreatedFile)
+	golden.RequireEqualRb(t, []byte(client.Content))
+	distBts, err := os.ReadFile(distFile)
+	require.NoError(t, err)
+	require.Equal(t, client.Content, string(distBts))
+}
