@@ -188,6 +188,8 @@ func getChangeloger(ctx *context.Context) (changeloger, error) {
 		return gitChangeloger{}, nil
 	case "github":
 		return newGitHubChangeloger(ctx)
+	case "gitlab":
+		return newGitLabChangeloger(ctx)
 	default:
 		return nil, fmt.Errorf("invalid changelog.use: %q", ctx.Config.Changelog.Use)
 	}
@@ -211,6 +213,24 @@ func newGitHubChangeloger(ctx *context.Context) (changeloger, error) {
 	}, nil
 }
 
+func newGitLabChangeloger(ctx *context.Context) (changeloger, error) {
+	cli, err := client.New(ctx)
+	if err != nil {
+		return nil, err
+	}
+	repo, err := git.ExtractRepoFromConfig()
+	if err != nil {
+		return nil, err
+	}
+	return &scmChangeloger{
+		client: cli,
+		repo: client.Repo{
+			Owner: repo.Owner,
+			Name:  repo.Name,
+		},
+	}, nil
+}
+
 func previous(tag string) (result string, err error) {
 	if tag := os.Getenv("GORELEASER_PREVIOUS_TAG"); tag != "" {
 		return tag, nil
