@@ -30,36 +30,42 @@ func createTemplateData() templateData {
 				OS:          "darwin",
 				DownloadURL: "https://github.com/caarlos0/test/releases/download/v0.1.3/test_Darwin_x86_64.tar.gz",
 				SHA256:      "1633f61598ab0791e213135923624eb342196b3494909c91899bcd0560f84c68",
+				Binaries:    []string{"bin1", "bin2", "bin3"},
 			},
 			{
 				Arch:        "arm64",
 				OS:          "darwin",
 				DownloadURL: "https://github.com/caarlos0/test/releases/download/v0.1.3/test_Darwin_arm64.tar.gz",
 				SHA256:      "1633f61598ab0791e213135923624eb342196b349490sadasdsadsadasdasdsd",
+				Binaries:    []string{"bin1", "bin2", "bin3"},
 			},
 			{
 				Arch:        "amd64",
 				OS:          "linux",
 				DownloadURL: "https://github.com/caarlos0/test/releases/download/v0.1.3/test_Linux_x86_64.tar.gz",
 				SHA256:      "1633f61598ab0791e213135923624eb342196b3494909c91899bcd0560f84c67",
+				Binaries:    []string{"bin1", "bin2", "bin3"},
 			},
 			{
 				Arch:        "arm",
 				OS:          "linux",
 				DownloadURL: "https://github.com/caarlos0/test/releases/download/v0.1.3/test_Arm6.tar.gz",
 				SHA256:      "1633f61598ab0791e213135923624eb342196b3494909c91899bcd0560f84c67",
+				Binaries:    []string{"bin1", "bin2", "bin3"},
 			},
 			{
 				Arch:        "arm64",
 				OS:          "linux",
 				DownloadURL: "https://github.com/caarlos0/test/releases/download/v0.1.3/test_Arm64.tar.gz",
 				SHA256:      "1633f61598ab0791e213135923624eb342196b3494909c91899bcd0560f84c67",
+				Binaries:    []string{"bin1", "bin2", "bin3"},
 			},
 			{
 				Arch:        "amd64",
 				OS:          "windows",
 				DownloadURL: "https://github.com/caarlos0/test/releases/download/v0.1.3/test_windows_amd64.zip",
 				SHA256:      "1633f61598ab0791e213135923624eb342196b3494909c91899bcd0560f84c67",
+				Binaries:    []string{"bin1.exe", "bin2.exe", "bin3.exe"},
 			},
 		},
 		Name:    "Test",
@@ -202,8 +208,9 @@ func TestFullPipe(t *testing.T) {
 				Goarch: "amd64",
 				Type:   artifact.UploadableArchive,
 				Extra: map[string]interface{}{
-					"ID":     "foo",
-					"Format": "tar.gz",
+					"ID":       "foo",
+					"Format":   "tar.gz",
+					"Binaries": []string{"name"},
 				},
 			})
 
@@ -230,6 +237,60 @@ func TestFullPipe(t *testing.T) {
 	}
 }
 
+func TestRunPipeUniversalBinary(t *testing.T) {
+	folder := t.TempDir()
+	ctx := &context.Context{
+		Git: context.GitInfo{
+			CurrentTag: "v1.0.1",
+		},
+		Version:   "1.0.1",
+		Artifacts: artifact.New(),
+		Config: config.Project{
+			Dist:        folder,
+			ProjectName: "unibin",
+			Rigs: []config.GoFish{
+				{
+					Name: "unibin",
+					Rig: config.RepoRef{
+						Owner: "unibin",
+						Name:  "bar",
+					},
+					IDs: []string{
+						"unibin",
+					},
+				},
+			},
+		},
+	}
+	path := filepath.Join(folder, "bin.tar.gz")
+	ctx.Artifacts.Add(&artifact.Artifact{
+		Name:   "unibin.tar.gz",
+		Path:   path,
+		Goos:   "darwin",
+		Goarch: "all",
+		Type:   artifact.UploadableArchive,
+		Extra: map[string]interface{}{
+			"ID":       "unibin",
+			"Format":   "tar.gz",
+			"Binaries": []string{"unibin"},
+		},
+	})
+
+	f, err := os.Create(path)
+	require.NoError(t, err)
+	require.NoError(t, f.Close())
+	client := client.NewMock()
+	distFile := filepath.Join(folder, "unibin.lua")
+
+	require.NoError(t, runAll(ctx, client))
+	require.NoError(t, publishAll(ctx, client))
+	require.True(t, client.CreatedFile)
+	golden.RequireEqualLua(t, []byte(client.Content))
+	distBts, err := os.ReadFile(distFile)
+	require.NoError(t, err)
+	require.Equal(t, client.Content, string(distBts))
+}
+
 func TestRunPipeNameTemplate(t *testing.T) {
 	folder := t.TempDir()
 	ctx := &context.Context{
@@ -266,8 +327,9 @@ func TestRunPipeNameTemplate(t *testing.T) {
 		Goarch: "amd64",
 		Type:   artifact.UploadableArchive,
 		Extra: map[string]interface{}{
-			"ID":     "foo",
-			"Format": "tar.gz",
+			"ID":       "foo",
+			"Format":   "tar.gz",
+			"Binaries": []string{"foo"},
 		},
 	})
 
@@ -344,8 +406,9 @@ func TestRunPipeMultipleGoFishWithSkip(t *testing.T) {
 		Goarch: "amd64",
 		Type:   artifact.UploadableArchive,
 		Extra: map[string]interface{}{
-			"ID":     "foo",
-			"Format": "tar.gz",
+			"ID":       "foo",
+			"Format":   "tar.gz",
+			"Binaries": []string{"foo"},
 		},
 	})
 
@@ -459,8 +522,9 @@ func TestRunPipeForMultipleArmVersions(t *testing.T) {
 					Goarm:  a.goarm,
 					Type:   artifact.UploadableArchive,
 					Extra: map[string]interface{}{
-						"ID":     a.name,
-						"Format": "tar.gz",
+						"ID":       a.name,
+						"Format":   "tar.gz",
+						"Binaries": []string{"foo"},
 					},
 				})
 				f, err := os.Create(path)
@@ -636,8 +700,9 @@ func TestRunPipeMultipleArchivesSameOsBuild(t *testing.T) {
 				Goarch: ttt.goarch,
 				Type:   artifact.UploadableArchive,
 				Extra: map[string]interface{}{
-					"ID":     fmt.Sprintf("foo%d", idx),
-					"Format": "tar.gz",
+					"ID":       fmt.Sprintf("foo%d", idx),
+					"Format":   "tar.gz",
+					"Binaries": []string{"foo"},
 				},
 			})
 		}
@@ -702,8 +767,9 @@ func TestRunPipeNoUpload(t *testing.T) {
 		Goarch: "amd64",
 		Type:   artifact.UploadableArchive,
 		Extra: map[string]interface{}{
-			"ID":     "foo",
-			"Format": "tar.gz",
+			"ID":       "foo",
+			"Format":   "tar.gz",
+			"Binaries": []string{"foo"},
 		},
 	})
 	client := client.NewMock()
