@@ -7,7 +7,6 @@ import (
 	"github.com/apex/log"
 	"github.com/goreleaser/goreleaser/internal/artifact"
 	"github.com/goreleaser/goreleaser/internal/git"
-	"github.com/goreleaser/goreleaser/internal/pipe"
 	"github.com/goreleaser/goreleaser/internal/tmpl"
 	"github.com/goreleaser/goreleaser/pkg/context"
 )
@@ -19,12 +18,12 @@ func (Pipe) String() string {
 	return "creating source archive"
 }
 
+func (Pipe) Skip(ctx *context.Context) bool {
+	return !ctx.Config.Source.Enabled
+}
+
 // Run the pipe.
 func (Pipe) Run(ctx *context.Context) (err error) {
-	if !ctx.Config.Source.Enabled {
-		return pipe.ErrSkipDisabledPipe
-	}
-
 	name, err := tmpl.New(ctx).Apply(ctx.Config.Source.NameTemplate)
 	if err != nil {
 		return err
